#
# spec file for package python-mockito
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python36 1
Name:           python-mockito
Version:        1.5.0
Release:        1.3
Summary:        Spying framework
License:        MIT
URL:            https://github.com/kaste/mockito-python
# https://github.com/kaste/mockito-python/issues/36
Source:         https://github.com/kaste/mockito-python/archive/%{version}.tar.gz
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%ifpython2
Requires:       python2-funcsigs
%endif
%python_subpackages

%description
Mockito is a spying framework originally based on the Java library with the same name.

%prep
%setup -q -n mockito-python-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc AUTHORS CHANGES.txt README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 1.5.0:
  * @Oracking fixed `expect` to support a string as its first
    argument.  All other functions supported that already.
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Release 1.4.0 (August 25, 2022)
  - @avandierast implemented `thenCallOriginalImplementation`.  See #60
    [#] Let `os.path.exists` use the real filesystem (often needed when
    [#] the testing framework needs itself a working `os.path.exists`
    [#] implementation) *but* fake a `.flake8` file.
    when(os.path).exists(...).thenCallOriginalImplementation()
    when(os.path).exists('.flake8').thenReturn(True)
- Release 1.3.5 (August 18, 2022)
  - Restore compatibility with Python 2.7
- Release 1.3.3 (June 23, 2022)
  - Hotfix: Correctly unstub methods extracted to the module level, for example ``random.randint()`` et.al. from the standard library.  See #53
- Release 1.3.2 (June 23, 2022)
  - Let `mock(spec=SomeClass)` work just as `mock(SomeClass)`
- Release 1.3.1 (June 14, 2022)
  - Reimplement `captor` to capture only during execution phase of a test.
- Release 1.3.0 (December 3, 2021)
  - Teach `captor` to remember all used values (@shashankrnr32). E.g.
    arg = captor()
    mock.do_something(123)
    mock.do_something(456)
    verify(mock).do_something(arg)
    assert arg.all_values == [123, 456]
* Thu Apr 22 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.2.2:
  * Fix typo in ``spy2`` doc
- Do not build for Python 3.6, due to no NumPy.
* Wed Apr  1 2020 pgajdos@suse.com
- version update to 1.2.1
  - @nielsvaneck fixed how we can lookup inherited classmethods.
  - Code base now is python 3 compatible. No 2to3 anymore.
  - Fine tune error messages on unexpected calls or verifications.
  - @felixonmars fixed a small compatibility issue with python 3.8
  - Mocking properties has become a bit easier. (#26)
* Mon Apr  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Disable python3 building as the mockito is py2 only (git master
  is py3 compatible so hopefully next release should be supported)
* Fri Apr  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1.1:
  * Added forget_invocations function. Thanks to @maximkulkin
  * Fix: The context manager (with) has now a proper implementation
  * Fix: Calling patch with two arguments can now be used with with
  * Fix: Do not treat the placeholder arguments (Ellipsis, args, kwargs) as special on call time anymore. (T.i. they only have a meaning when stubbing or verifying.)
  * Enhancement: Changed some truthy or equality tests to identity (is) tests. This reduces edge-cases where some user object defines __eq__ or __bool__. (Hello _numpy_!)
- Run tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Dec 11 2017 sebix+novell.com@sebix.at
- update to version 1.0.12
  * see CHANGES.txt for a detailed changelog
  * changes in version 1.0.12:
  - Better error messages for failed verifications.
  * changes in version 1.0.7 - 1.0.10
  - ``verifyZeroInteractions`` implemented. This is actually a *breaking change*, because ``verifyZeroInteractions`` was an alias for ``verifyNoMoreInteractions`` (sic!).
  - All `verify*` functions now warn you if you pass in an object which was never stubbed.
  * changes in version 1.0.0 - 1.0.5
  - mockito's strict mode is far more strict than before
  - ``mock``, ``when``, ``verify`` return mostly empty objects. It is unlikely to have a method_name clash.
  - ``Mock()`` is now an implementation detail; it is **not** exported anymore. Use ``mock()``.
  * changes in version 0.7.1:
  - bugfixes
  * changes in version 0.7.0:
  - bugfixes
  * changes in version 0.6.1:
  - Added ``thenAnswer(callable)``. The callable will be called to compute the answer the stubbed method will return. For that it will receive the arguments of the caller.
  * changes in version 0.6.0:
  - Breaking change: Throw early when calling not expected methods in strict mode.
  * changes in version 0.5.3:
  - Remove hard coded distribute setup files.
- Remove no longer needed patch python-mockito-0.5.2-setup.py.patch
* Sun Dec  8 2013 p.drouand@gmail.com
- Update to version 0.5.2
  + No changelog available
- Remove redundant %%clean section
- Adapt setup.py.patch to upstream changes
- Rename it to respect standard naming conventions
- Remove python-mockito.rpmlintrc; problem of execution bits have
  been fixed by upstream
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Thu Jul 18 2013 berendt@b1-systems.de
- added python-mockito.rpmlintrc
- added setup.py.patch to make package buildable on SLES11 SP3
* Thu Jul 18 2013 berendt@b1-systems.de
- added missing python-mockito.changes file
- cleaning up the SPEC
